# == Class: postfix
#
# Full description of class postfix here.
#
# === Parameters
#
# Document parameters here.
#
# [*smtprelayhost*]
#   The host to use to relay smtp messages.
#   This is required, and has no default value.
#
# [*smtprelayport*]
#   The port to use to relay smtp messages.
#   This defaults to '25' unless specified.
#
# === Variables
#
# Here you should define a list of variables that this module would require.
#
# [*sample_variable*]
#   Explanation of how this variable affects the funtion of this class and if it
#   has a default. e.g. "The parameter enc_ntp_servers must be set by the
#   External Node Classifier as a comma separated list of hostnames." (Note,
#   global variables should not be used in preference to class parameters  as of
#   Puppet 2.6.)
#
# === Examples
#
#  class { postfix:
#    smtprelayhost => 'smtp.yourdomain.com',
#    smtprelayport => 25,
#  }
#
# === Authors
#
# Tim McLaughlin <nospam@macwebb.com>
#
# === Copyright
#
# Meh
#
class postfix
(
	$smtprelayhost,
	$smtprelayport = 25
)
{

	include postfix::params

	# Make sure the package is installed
	package { $params::packageName :
		ensure	=> latest,
	}

	# Make sure the service is running
	service { $params::serviceName :
		ensure	=> running,
		require	=> Package[ $params::packageName ],
	}

	# Pick the template path we're going to use
	$mod_path = get_module_path('postfix')
	$specific = "$mod_path/templates/$operatingsystem/$operatingsystemrelease$params::configDestPath.erb"
	$default  = "$mod_path/templates/default$params::configDestPath.erb"

	file { $params::configDestPath :
		owner	=> 'root',
		group	=> 'root',
		content	=> inline_template( file( $specific, $default ) ),
		notify	=> Service[ $params::serviceName ],
	}
}
